package compbio.ws.client;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertNotNull;
import static org.testng.Assert.fail;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.net.URL;
import java.util.HashSet;
import java.util.List;

import javax.xml.namespace.QName;
import javax.xml.ws.Service;

import org.testng.annotations.Test;

import compbio.conservation.Method;
import compbio.data.msa.Annotation;
import compbio.data.sequence.FastaSequence;
import compbio.data.sequence.Score;
import compbio.data.sequence.SequenceUtil;
import compbio.metadata.JobSubmissionException;
import compbio.metadata.LimitExceededException;
import compbio.metadata.ResultNotAvailableException;
import compbio.metadata.UnsupportedRuntimeException;
import compbio.util.SysPrefs;
import compbio.ws.server.AAConWS;

public class TestAAConWS {

	@Test
	public void test() throws FileNotFoundException, IOException {

		URL url = new URL("http://localhost:8080/jabaws/AAConWS?wsdl");
		String namespace = "http://msa.data.compbio/01/12/2010/";
		QName qname = new QName(namespace, "AAConWS");
		Service serv = Service.create(url, qname);
		/*
		 * MsaWS msaws = serv.getPort(new QName(
		 * "http://msa.data.compbio/01/01/2010/", "ClustalWSPort"),
		 * MsaWS.class);
		 */
		// Annotation<AACon> msaws = serv.getPort(new QName(namespace,
		// "ClustalWSPort"), Annotation.class);

		Annotation<AAConWS> msaws = serv.getPort(new QName(namespace,
				"AAConWSPort"), Annotation.class);

		// List<FastaSequence> fsl = SequenceUtil.readFasta(new FileInputStream(
		// AAConTester.test_alignment_input));

		String CURRENT_DIRECTORY = SysPrefs.getCurrentDirectory()
				+ File.separator;

		List<FastaSequence> fsl = SequenceUtil.readFasta(new FileInputStream(
				CURRENT_DIRECTORY + "testsrc" + File.separator + "testdata"
						+ File.separator + "TO1381.fasta.aln"));

		try {
			System.out.println("Pres: "
					+ msaws.getPresets().getPresets().get(0));
			String jobId = msaws.analize(fsl);
			System.out.println("J: " + jobId);
			HashSet<Score> result = msaws.getConservation(jobId);
			assertNotNull(result);
			assertEquals(result.size(), 1);
			assertEquals(result.iterator().next().getMethod(), Method.SHENKIN);
			List<Float> scores = result.iterator().next().getScores();
			assertNotNull(scores);
			assertEquals(scores.size(), 568);

		} catch (UnsupportedRuntimeException e) {
			e.printStackTrace();
			fail(e.getMessage());
		} catch (LimitExceededException e) {
			e.printStackTrace();
			fail(e.getMessage());
		} catch (JobSubmissionException e) {
			e.printStackTrace();
			fail(e.getMessage());
		} catch (ResultNotAvailableException e) {
			e.printStackTrace();
			fail(e.getMessage());
		}

	}
}
